==> elements-0.1.86.tar.gz: lib/src/MultiselectElement.dart <==
// Copyright (c) 2015, Patrick Minogue. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

library MultiSelect;

import 'dart:html';
import 'Elements_base.dart';

/// NOT FINISHED
/// TODO ADD CSS CLASS, TESTING, ETC


// Multiselect element
class MultiselectElement extends afElement 
{
  MultiselectElement(this._container, List<String> options, [this._required = false])
  {
    if (options == null) throw new ArgumentError.notNull("options");      
            
    _container.classes.add("multi-select");
    _selectedOptionsContainer = new DivElement();
    _options = new SelectElement();
    _addElement = new DivElement();
    _addElement.innerHtml = "Lägg till";
    _addElement.className = "add-button no-select";
    _addElement.onClick.listen(_addSelected);  
    
    options.forEach((String value)
    {
      OptionElement option = new OptionElement();
      option.innerHtml = option.value = value;
      _options.children.add(option);
    });
   
    _container.children.add(_options);
    _container.children.add(_addElement);
    _container.children.add(_selectedOptionsContainer);        
    _options.setCustomValidity(""); 
  }
  
  void _add(String option)
  {
    try
    {
      _options.options.firstWhere((OptionElement o) => o.value == option).remove();
    }
    on StateError catch (e, s) 
    { 
      print(e);
      print(s);
      return;
    }
    
    DivElement addedOption = new DivElement();    
    addedOption.className = "added-option no-select";
    
    SpanElement label = new SpanElement();
    label.innerHtml = option;
       
    ImageElement close = new ImageElement();
    close.src = "graphics/close.png";    
    close.onClick.listen((_) => _remove(addedOption));

    addedOption.children.add(label);
    addedOption.children.add(close);
    _selectedOptionsContainer.children.add(addedOption); 
    
    _options.setCustomValidity("");
  }
  
  void _addSelected([Event e = null])
  {
    if (_options.selectedIndex < 0) return;
    
    DivElement addedOption = new DivElement();    
    addedOption.className = "added-option no-select";
    
    SpanElement label = new SpanElement();
    label.innerHtml = _options.selectedOptions.first.innerHtml;
       
    ImageElement close = new ImageElement();
    close.src = "graphics/close.png";    
    close.onClick.listen((_) => _remove(addedOption));

    addedOption.children.add(label);
    addedOption.children.add(close);
    _selectedOptionsContainer.children.add(addedOption);
    _options.selectedOptions.first.remove();
    
    _options.setCustomValidity("");
  }
  
  void _remove(DivElement addedOption)
  {
    OptionElement option = new OptionElement();    
    option.innerHtml = option.value = addedOption.children.first.innerHtml;
    _options.children.add(option);
    _selectedOptionsContainer.children.remove(addedOption);
    if (_selectedOptionsContainer.children.isEmpty)
    {
      _options.setCustomValidity(""); 
      _options.setCustomValidity("Please select at least one alternative");
    }
  }
  
  bool get valid
  {
    if (_required == true && _selectedOptionsContainer.children.isEmpty)
    {
      return false;
    }
    /// else   
    return true;
  }
  
  String get value
  {
    String values = "";
    _selectedOptionsContainer.children.forEach((DivElement e)
    {
      values += e.children.first.innerHtml + ", ";  
    });    
    
    if (values.length > 2) values = values.substring(0, values.length - 2);
    return values;
  }
  
  set value(String values)
  {
    _selectedOptionsContainer.children.clear();
    
    if (values.length > 2)
    {
      List<String> valueList = values.split(", ");
      
      valueList.forEach((String value)
      {
        _add(value);
      });
    }
  }
  
  bool _required;
  SelectElement _options;
  DivElement _addElement;
  DivElement _selectedOptionsContainer;
  DivElement _container;
}

==> elements-0.1.89.tar.gz: lib/src/MultiselectElement.dart <==
// Copyright (c) 2015, Patrick Minogue. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

library MultiSelect;

import 'dart:html';
import 'Elements_base.dart';

/// NOT FINISHED
/// TODO ADD CSS CLASS, TESTING, ETC


// Multiselect element
class MultiselectElement extends afElement 
{
  MultiselectElement(this._container, List<String> options, [this._required = false])
  {
    if (options == null) throw new ArgumentError.notNull("options");      
            
    _container.classes.add("multi-select");
    _selectedOptionsContainer = new DivElement();
    _options = new SelectElement();
    _addElement = new DivElement();
    _addElement.innerHtml = "Add";
    _addElement.className = "add-button no-select";
    _addElement.onClick.listen(_addSelected);  
    
    options.forEach((String value)
    {
      OptionElement option = new OptionElement();
      option.innerHtml = option.value = value;
      _options.children.add(option);
    });
   
    _container.children.add(_options);
    _container.children.add(_addElement);
    _container.children.add(_selectedOptionsContainer);        
    _options.setCustomValidity(""); 
  }
  
  void _add(String option)
  {
    try
    {
      _options.options.firstWhere((OptionElement o) => o.value == option).remove();
    }
    on StateError catch (e, s) 
    { 
      print(e);
      print(s);
      return;
    }
    
    DivElement addedOption = new DivElement();    
    addedOption.className = "added-option no-select";
    
    SpanElement label = new SpanElement();
    label.innerHtml = option;
       
    ImageElement close = new ImageElement();
    close.src = "graphics/close.png";    
    close.onClick.listen((_) => _remove(addedOption));

    addedOption.children.add(label);
    addedOption.children.add(close);
    _selectedOptionsContainer.children.add(addedOption); 
    
    _options.setCustomValidity("");
  }
  
  void _addSelected([Event e = null])
  {
    if (_options.selectedIndex < 0) return;
    
    DivElement addedOption = new DivElement();    
    addedOption.className = "added-option no-select";
    
    SpanElement label = new SpanElement();
    label.innerHtml = _options.selectedOptions.first.innerHtml;
       
    ImageElement close = new ImageElement();
    close.src = "graphics/close.png";    
    close.onClick.listen((_) => _remove(addedOption));

    addedOption.children.add(label);
    addedOption.children.add(close);
    _selectedOptionsContainer.children.add(addedOption);
    _options.selectedOptions.first.remove();
    
    _options.setCustomValidity("");
  }
  
  void _remove(DivElement addedOption)
  {
    OptionElement option = new OptionElement();    
    option.innerHtml = option.value = addedOption.children.first.innerHtml;
    _options.children.add(option);
    _selectedOptionsContainer.children.remove(addedOption);
    if (_selectedOptionsContainer.children.isEmpty)
    {
      _options.setCustomValidity(""); 
      _options.setCustomValidity("Please select at least one alternative");
    }
  }
  
  bool get valid
  {
    if (_required == true && _selectedOptionsContainer.children.isEmpty)
    {
      return false;
    }
    /// else   
    return true;
  }
  
  String get value
  {
    String values = "";
    _selectedOptionsContainer.children.forEach((DivElement e)
    {
      values += e.children.first.innerHtml + ", ";  
    });    
    
    if (values.length > 2) values = values.substring(0, values.length - 2);
    return values;
  }
  
  set value(String values)
  {
    _selectedOptionsContainer.children.clear();
    
    if (values.length > 2)
    {
      List<String> valueList = values.split(", ");
      
      valueList.forEach((String value)
      {
        _add(value);
      });
    }
  }
  
  set buttonLabel(String value)
  {
    _addElement.setInnerHtml(value);
  }
  
  bool _required;
  SelectElement _options;
  DivElement _addElement;
  DivElement _selectedOptionsContainer;
  DivElement _container;
}
